@@ -106,8 +106,10 @@ builder_bind_combobox (GtkBuilder *builder, XtmSettings *settings)
 static void
 show_about_dialog (GtkWidget *widget, gpointer user_data)
 {
+	GtkDialog *dialog = GTK_DIALOG (user_data);
+
 	const gchar *authors[] = {
-		"(c) 2014-2020 Simon Steinbeiss",
+		"(c) 2014-2021 Simon Steinbeiss",
 		"(c) 2018-2019 Rozhuk Ivan",
 		"(c) 2014 Landry Breuil",
 		"(c) 2014 Harald Judt",
@@ -137,24 +139,25 @@ show_about_dialog (GtkWidget *widget, gpointer user_data)
 		"the Free Software Foundation; either version 2 of the License, or\n"
 		"(at your option) any later version.\n";
 
-	gtk_show_about_dialog (GTK_WINDOW (widget),
+	gtk_show_about_dialog (GTK_WINDOW (dialog),
 		"program-name", _("Task Manager"),
 		"version", PACKAGE_VERSION,
-		"copyright", "Copyright \302\251 2005-2020 The Xfce development team",
+		"copyright", "Copyright \302\251 2005-2021 The Xfce development team",
 		"logo-icon-name", "org.xfce.taskmanager",
 		"comments", _("Easy to use task manager"),
 		"license", license,
 		"authors", authors,
 		"translator-credits", _("translator-credits"),
 		"website", "https://docs.xfce.org/apps/xfce4-taskmanager/start",
-		"website-label", "docs.xfce.org",
 		NULL);
 }
 
 static void
 show_help (GtkWidget *widget, gpointer user_data)
 {
-	xfce_dialog_show_help_with_version (GTK_WINDOW (widget), "xfce4-taskmanager", "start", NULL, NULL);
+	GtkDialog *dialog = GTK_DIALOG (user_data);
+
+	xfce_dialog_show_help_with_version (GTK_WINDOW (dialog), "xfce4-taskmanager", "start", NULL, NULL);
 }
 
 static void
@@ -198,7 +201,7 @@ xtm_settings_dialog_new (GtkBuilder *builder, GtkWidget *parent_window)
 	builder_bind_toggle_button (builder, "ppid", settings, "column-ppid");
 	builder_bind_toggle_button (builder, "state", settings, "column-state");
 	builder_bind_toggle_button (builder, "vbytes", settings, "column-vsz");
-	builder_bind_toggle_button (builder, "pbytes", settings, "column-rss");
+	builder_bind_toggle_button (builder, "rbytes", settings, "column-rss");
 	builder_bind_toggle_button (builder, "uid", settings, "column-uid");
 	builder_bind_toggle_button (builder, "cpu", settings, "column-cpu");
 	builder_bind_toggle_button (builder, "priority", settings, "column-priority");
